==> cresce_ui-0.8.14.tar.gz: lib/src/c_week_picker.dart <==
part of cresce_ui;

class CWeekPicker extends StatelessWidget {
  final void Function(List<int> weekdays)? onChange;
  final List<int> weekdays = [];

  CWeekPicker({Key? key, this.onChange}) : super(key: key);

  @override
  Widget build(BuildContext context) {
    var dateFormat = DateFormat('E');
    return Row(
      children: [
        CToggleRoundButton(
          label: dateFormat.format(DateTime(2022, 1, 3)),
          onTap: () => onWeekdayTap(1),
        ),
        const SizedBox(width: 25),
        CToggleRoundButton(
          label: dateFormat.format(DateTime(2022, 1, 4)),
          onTap: () => onWeekdayTap(2),
        ),
        const SizedBox(width: 25),
        CToggleRoundButton(
          label: dateFormat.format(DateTime(2022, 1, 5)),
          onTap: () => onWeekdayTap(3),
        ),
        const SizedBox(width: 25),
        CToggleRoundButton(
          label: dateFormat.format(DateTime(2022, 1, 6)),
          onTap: () => onWeekdayTap(4),
        ),
        const SizedBox(width: 25),
        CToggleRoundButton(
          label: dateFormat.format(DateTime(2022, 1, 7)),
          onTap: () => onWeekdayTap(5),
        ),
        const SizedBox(width: 25),
        CToggleRoundButton(
          label: dateFormat.format(DateTime(2022, 1, 8)),
          onTap: () => onWeekdayTap(6),
        ),
      ],
    );
  }

  void onWeekdayTap(int weekday) {
    if (weekdays.contains(weekday)) {
      weekdays.remove(weekday);
    } else {
      weekdays.add(weekday);
    }
    weekdays.sort();
    onChange?.call(weekdays);
  }
}

class CToggleRoundButton extends StatefulWidget {
  final String label;
  final VoidCallback? onTap;

  const CToggleRoundButton({Key? key, this.onTap, required this.label})
      : super(key: key);

  @override
  State<CToggleRoundButton> createState() => _CToggleRoundButtonState();
}

class _CToggleRoundButtonState extends State<CToggleRoundButton> {
  late CButtonStyle currentStyle;
  late bool state = false;

  @override
  void initState() {
    super.initState();
    currentStyle = const CPrimaryStyle();
    state = false;
  }

  @override
  Widget build(BuildContext context) {
    return GestureDetector(
      onTap: () {
        _toggle();
        widget.onTap?.call();
      },
      child: Container(
        width: 70.0,
        height: 70.0,
        decoration: BoxDecoration(
          color: currentStyle.getDefaultState().backgroundColor,
          borderRadius:
              const BorderRadius.all(Radius.elliptical(9999.0, 9999.0)),
          border: Border.all(
              width: 1.0, color: currentStyle.getDefaultState().borderColor),
          boxShadow: const [CBoxShadow()],
        ),
        child: Center(
          child: Text(
            widget.label,
            style: currentStyle.getDefaultState().labelStyle,
          ),
        ),
      ),
    );
  }

  _toggle() {
    if (!state) {
      currentStyle = const CSecondaryStyle();
    } else {
      currentStyle = const CPrimaryStyle();
    }
    state = !state;
    setState(() {});
  }
}

==> cresce_ui-0.9.4.tar.gz: lib/src/c_week_picker.dart <==
part of '../cresce_ui.dart';

class CWeekPicker extends StatelessWidget {
  final void Function(List<int> weekdays)? onChange;
  final List<int> weekdays = [];

  CWeekPicker({super.key, this.onChange});

  @override
  Widget build(BuildContext context) {
    var dateFormat = DateFormat('E');
    return Row(
      children: [
        CToggleRoundButton(
          label: dateFormat.format(DateTime(2022, 1, 3)),
          onTap: () => onWeekdayTap(1),
        ),
        const SizedBox(width: 25),
        CToggleRoundButton(
          label: dateFormat.format(DateTime(2022, 1, 4)),
          onTap: () => onWeekdayTap(2),
        ),
        const SizedBox(width: 25),
        CToggleRoundButton(
          label: dateFormat.format(DateTime(2022, 1, 5)),
          onTap: () => onWeekdayTap(3),
        ),
        const SizedBox(width: 25),
        CToggleRoundButton(
          label: dateFormat.format(DateTime(2022, 1, 6)),
          onTap: () => onWeekdayTap(4),
        ),
        const SizedBox(width: 25),
        CToggleRoundButton(
          label: dateFormat.format(DateTime(2022, 1, 7)),
          onTap: () => onWeekdayTap(5),
        ),
        const SizedBox(width: 25),
        CToggleRoundButton(
          label: dateFormat.format(DateTime(2022, 1, 8)),
          onTap: () => onWeekdayTap(6),
        ),
      ],
    );
  }

  void onWeekdayTap(int weekday) {
    if (weekdays.contains(weekday)) {
      weekdays.remove(weekday);
    } else {
      weekdays.add(weekday);
    }
    weekdays.sort();
    onChange?.call(weekdays);
  }
}

class CToggleRoundButton extends StatefulWidget {
  final String label;
  final VoidCallback? onTap;

  const CToggleRoundButton({super.key, this.onTap, required this.label});

  @override
  State<CToggleRoundButton> createState() => _CToggleRoundButtonState();
}

class _CToggleRoundButtonState extends State<CToggleRoundButton> {
  late CButtonStyle currentStyle;
  late bool state = false;

  @override
  void initState() {
    super.initState();
    currentStyle = const CPrimaryStyle();
    state = false;
  }

  @override
  Widget build(BuildContext context) {
    return GestureDetector(
      onTap: () {
        _toggle();
        widget.onTap?.call();
      },
      child: Container(
        width: 70.0,
        height: 70.0,
        decoration: BoxDecoration(
          color: currentStyle.getDefaultState().backgroundColor,
          borderRadius:
              const BorderRadius.all(Radius.elliptical(9999.0, 9999.0)),
          border: Border.all(
              width: 1.0, color: currentStyle.getDefaultState().borderColor),
          boxShadow: const [CBoxShadow()],
        ),
        child: Center(
          child: Text(
            widget.label,
            style: currentStyle.getDefaultState().labelStyle,
          ),
        ),
      ),
    );
  }

  _toggle() {
    if (!state) {
      currentStyle = const CSecondaryStyle();
    } else {
      currentStyle = const CPrimaryStyle();
    }
    state = !state;
    setState(() {});
  }
}
